@@ -1,17 +1,17 @@
 """Configuration and examples for individual rules."""
 
-from sqlfluff.core.rules.base import (
-    RuleSet,
-    RulePack,
-    BaseRule,
-    LintResult,
-    LintFix,
-    RuleGhost,
-    EvalResultType,
-)
-from sqlfluff.core.rules.context import RuleContext
-from sqlfluff.core.rules.config_info import STANDARD_CONFIG_INFO_DICT
 from sqlfluff.core.plugin.host import get_plugin_manager
+from sqlfluff.core.rules.base import (
+    BaseRule,
+    EvalResultType,
+    LintResult,
+    RuleGhost,
+    RulePack,
+    RuleSet,
+)
+from sqlfluff.core.rules.config_info import STANDARD_CONFIG_INFO_DICT
+from sqlfluff.core.rules.context import RuleContext
+from sqlfluff.core.rules.fix import LintFix
 
 
 def _load_standard_rules() -> RuleSet:
