@@ -127,7 +127,11 @@ class JinjaTemplater(PythonTemplater):
 
     @classmethod
     def _extract_macros_from_path(
-        cls, path: List[str], env: Environment, ctx: Dict
+        cls,
+        path: List[str],
+        env: Environment,
+        ctx: Dict,
+        exclude_paths: Optional[List[str]] = None,
     ) -> dict:
         """Take a path and extract macros from it.
 
@@ -135,6 +139,7 @@ class JinjaTemplater(PythonTemplater):
             path (List[str]): A list of paths.
             env (Environment): The environment object.
             ctx (Dict): The context dictionary.
+            exclude_paths (Optional[[List][str]]): A list of paths to exclude
 
         Returns:
             dict: A dictionary containing the extracted macros.
@@ -150,6 +155,11 @@ class JinjaTemplater(PythonTemplater):
                 raise ValueError(f"Path does not exist: {path_entry}")
 
             if os.path.isfile(path_entry):
+                if exclude_paths:
+                    if cls._exclude_macros(
+                        macro_path=path_entry, exclude_macros_path=exclude_paths
+                    ):
+                        continue
                 # It's a file. Extract macros from it.
                 with open(path_entry) as opened_file:
                     template = opened_file.read()
@@ -172,7 +182,10 @@ class JinjaTemplater(PythonTemplater):
                         if fname.endswith(".sql"):
                             macro_ctx.update(
                                 cls._extract_macros_from_path(
-                                    [os.path.join(dirpath, fname)], env=env, ctx=ctx
+                                    [os.path.join(dirpath, fname)],
+                                    env=env,
+                                    ctx=ctx,
+                                    exclude_paths=exclude_paths,
                                 )
                             )
         return macro_ctx
@@ -352,8 +365,10 @@ class JinjaTemplater(PythonTemplater):
         Returns:
             jinja2.Environment: A properly configured jinja environment.
         """
-        # We explicitly want to preserve newlines.
-        macros_path = self._get_macros_path(config)
+        macros_path = self._get_macros_path(config, "load_macros_from_path")
+        loader_search_path = self._get_loader_search_path(config)
+        final_search_path = (loader_search_path or []) + (macros_path or [])
+
         ignore_templating = config and "templating" in config.get("ignore")
         if ignore_templating:
 
@@ -375,14 +390,15 @@ class JinjaTemplater(PythonTemplater):
                         value = os.path.splitext(os.path.basename(str(name)))[0]
                         return value, f"{value}.sql", lambda: False
 
-            loader = SafeFileSystemLoader(macros_path or [])
+            loader = SafeFileSystemLoader(final_search_path or [])
         else:
-            loader = FileSystemLoader(macros_path) if macros_path else None
+            loader = FileSystemLoader(final_search_path) if final_search_path else None
         extensions = ["jinja2.ext.do"]
         if self._apply_dbt_builtins(config):
             extensions.append(DBTTestExtension)
 
         return SandboxedEnvironment(
+            # We explicitly want to preserve newlines.
             keep_trailing_newline=True,
             # The do extension allows the "do" directive
             autoescape=False,
@@ -390,11 +406,11 @@ class JinjaTemplater(PythonTemplater):
             loader=loader,
         )
 
-    def _get_macros_path(self, config: FluffConfig) -> Optional[List[str]]:
+    def _get_macros_path(self, config: FluffConfig, key: str) -> Optional[List[str]]:
         """Get the list of macros paths from the provided config object.
 
         This method searches for a config section specified by the
-        templater_selector, name, and 'load_macros_from_path' keys. If the section is
+        templater_selector, name, and key specified. If the section is
         found, it retrieves the value associated with that section and splits it into
         a list of strings using a comma as the delimiter. The resulting list is
         stripped of whitespace and empty strings and returned. If the section is not
@@ -403,23 +419,49 @@ class JinjaTemplater(PythonTemplater):
         Args:
             config (FluffConfig): The config object to search for the macros path
                 section.
+            key (str): Key to load the macros path from the config file.
+                Also used for loading the excluding macros path from config.
 
         Returns:
             Optional[List[str]]: The list of macros paths if found, None otherwise.
         """
         if config:
-            macros_path = config.get_section(
-                (self.templater_selector, self.name, "load_macros_from_path")
-            )
+            macros_path = config.get_section((self.templater_selector, self.name, key))
             if macros_path:
                 result = [s.strip() for s in macros_path.split(",") if s.strip()]
                 if result:
                     return result
         return None
 
-    def _get_jinja_analyzer(
-        self, raw_str: str, env: Environment, config: Optional[FluffConfig] = None
-    ) -> JinjaAnalyzer:
+    def _get_loader_search_path(self, config: FluffConfig) -> Optional[List[str]]:
+        """Get the list of Jinja loader search paths from the provided config object.
+
+        This method searches for a config section specified by the
+        templater_selector, name, and 'loader_search_path' keys. If the section is
+        found, it retrieves the value associated with that section and splits it into
+        a list of strings using a comma as the delimiter. The resulting list is
+        stripped of whitespace and empty strings and returned. If the section is not
+        found or the resulting list is empty, it returns None.
+
+        Args:
+            config (FluffConfig): The config object to search for the loader search
+                path section.
+
+        Returns:
+            Optional[List[str]]: The list of loader search paths if found, None
+                otherwise.
+        """
+        if config:
+            loader_search_path = config.get_section(
+                (self.templater_selector, self.name, "loader_search_path")
+            )
+            if loader_search_path:
+                result = [s.strip() for s in loader_search_path.split(",") if s.strip()]
+                if result:
+                    return result
+        return None
+
+    def _get_jinja_analyzer(self, raw_str: str, env: Environment) -> JinjaAnalyzer:
         """Creates a new object derived from JinjaAnalyzer.
 
         Derived classes can provide their own analyzers (e.g. to support custom Jinja
@@ -484,11 +526,17 @@ class JinjaTemplater(PythonTemplater):
 
         # Load macros from path (if applicable)
         if config:
-            macros_path = self._get_macros_path(config)
+            macros_path = self._get_macros_path(config, "load_macros_from_path")
+            exclude_macros_path = self._get_macros_path(
+                config, "exclude_macros_from_path"
+            )
             if macros_path:
                 live_context.update(
                     self._extract_macros_from_path(
-                        macros_path, env=env, ctx=live_context
+                        macros_path,
+                        env=env,
+                        ctx=live_context,
+                        exclude_paths=exclude_macros_path,
                     )
                 )
 
@@ -682,7 +730,7 @@ class JinjaTemplater(PythonTemplater):
                 (
                     "Unrecoverable failure in Jinja templating: {}. Have you "
                     "correctly configured your variables? "
-                    "https://docs.sqlfluff.com/en/latest/configuration.html"
+                    "https://docs.sqlfluff.com/en/latest/perma/variables.html"
                 ).format(err),
                 # We don't have actual line number information, but specify
                 # line 1 so users can ignore with "noqa" if they want. (The
@@ -713,7 +761,7 @@ class JinjaTemplater(PythonTemplater):
 
         templater_logger.info("Slicing File Template")
         templater_logger.debug("    Raw String: %r", raw_str[:80])
-        analyzer = self._get_jinja_analyzer(raw_str, self._get_jinja_env(), config)
+        analyzer = self._get_jinja_analyzer(raw_str, self._get_jinja_env())
         tracer = analyzer.analyze(render_func)
         trace = tracer.trace(append_to_templated=kwargs.pop("append_to_templated", ""))
         return trace.raw_sliced, trace.sliced_file, trace.templated_str
@@ -812,7 +860,6 @@ class JinjaTemplater(PythonTemplater):
         render_func: Callable[[str], str],
         uncovered_slices: Set[int],
         append_to_templated="",
-        config: Optional[FluffConfig] = None,
     ):
         """Address uncovered slices by tweaking the template to hit them.
 
@@ -826,9 +873,8 @@ class JinjaTemplater(PythonTemplater):
                 raw source file.
             append_to_templated (:obj:`str`, optional): Optional string to append
                 to the templated file.
-            config (:obj:`FluffConfig`, optional): Optional config object.
         """
-        analyzer = self._get_jinja_analyzer(in_str, self._get_jinja_env(), config)
+        analyzer = self._get_jinja_analyzer(in_str, self._get_jinja_env())
         tracer_copy = analyzer.analyze(render_func)
 
         max_variants_generated = 10
@@ -884,7 +930,7 @@ class JinjaTemplater(PythonTemplater):
             variant_raw_str = "".join(variant_key)
             if variant_raw_str not in variants:
                 analyzer = self._get_jinja_analyzer(
-                    variant_raw_str, self._get_jinja_env(), config
+                    variant_raw_str, self._get_jinja_env()
                 )
                 tracer_trace = analyzer.analyze(render_func)
                 try:
@@ -984,7 +1030,7 @@ class JinjaTemplater(PythonTemplater):
         _, _, render_func = self.construct_render_func(fname=fname, config=config)
 
         for raw_sliced, sliced_file, templated_str in self._handle_unreached_code(
-            in_str, render_func, uncovered_literal_idxs, config=config
+            in_str, render_func, uncovered_literal_idxs
         ):
             yield (
                 TemplatedFile(
@@ -997,6 +1043,27 @@ class JinjaTemplater(PythonTemplater):
                 violations,
             )
 
+    @staticmethod
+    def _exclude_macros(macro_path: str, exclude_macros_path: List[str]) -> bool:
+        """Determines if a macro is within the exclude macros path.
+
+        These macros will be ignored and not loaded into context
+
+        Args:
+            macro_path (str): The raw string to be sliced.
+            exclude_macros_path (List[str]): The rendering function to be used.
+
+        Returns:
+            bool: True if the macro should be excluded
+        """
+        for exclude_path in exclude_macros_path:
+            macro_path_abs = os.path.abspath(macro_path)
+            exclude_path_abs = os.path.abspath(exclude_path)
+            if exclude_path_abs in macro_path_abs:
+                templater_logger.debug("Skipping this macro file: %s", macro_path)
+                return True
+        return False
+
 
 class DummyUndefined(jinja2.Undefined):
     """Acts as a dummy value to try and avoid template failures.
