@@ -534,6 +534,8 @@ class StatementSegment(ansi.StatementSegment):
             Ref("DropReservationStatementSegment"),
             Ref("CreateAssignmentStatementSegment"),
             Ref("DropAssignmentStatementSegment"),
+            Ref("DropTableFunctionStatementSegment"),
+            Ref("CreateTableFunctionStatementSegment"),
         ],
     )
 
@@ -1717,6 +1719,68 @@ class CreateSchemaStatementSegment(ansi.CreateSchemaStatementSegment):
     )
 
 
+class CreateTableFunctionStatementSegment(BaseSegment):
+    """A `CREATE TABLE FUNCTION` statement."""
+
+    # https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language#create_table_function_statement
+
+    type = "create_table_function_statement"
+
+    match_grammar = Sequence(
+        "CREATE",
+        Ref("OrReplaceGrammar", optional=True),
+        "TABLE",
+        "FUNCTION",
+        Ref("IfNotExistsGrammar", optional=True),
+        Ref("TableReferenceSegment"),
+        # Column list for input parameters
+        Sequence(
+            Bracketed(
+                Delimited(
+                    Ref("ColumnDefinitionSegment"),
+                    allow_trailing=True,
+                    optional=True,
+                )
+            ),
+            optional=True,
+        ),
+        # Column list for the schema of the table that the function returns
+        Sequence(
+            "RETURNS",
+            "TABLE",
+            Bracketed(
+                Delimited(  # Comma-separated list of field names/types
+                    Sequence(
+                        Ref("ParameterNameSegment"),
+                        Ref("DatatypeSegment"),
+                    ),
+                ),
+                bracket_type="angle",
+                bracket_pairs_set="angle_bracket_pairs",
+            ),
+            optional=True,
+        ),
+        Sequence(
+            "AS",
+            OptionallyBracketed(Ref("SelectableGrammar")),
+        ),
+    )
+
+
+class DropTableFunctionStatementSegment(BaseSegment):
+    """A `DROP TABLE FUNCTION` statement."""
+
+    type = "drop_table_function_statement"
+
+    match_grammar: Matchable = Sequence(
+        "DROP",
+        "TABLE",
+        "FUNCTION",
+        Ref("IfExistsGrammar", optional=True),
+        Delimited(Ref("TableReferenceSegment")),
+    )
+
+
 class CreateTableStatementSegment(ansi.CreateTableStatementSegment):
     """`CREATE TABLE` statement.
 
