@@ -28,11 +28,15 @@ from sqlfluff.core.parser import (
     SegmentGenerator,
     Sequence,
     StringLexer,
+    StringParser,
     SymbolSegment,
     TypedParser,
 )
 from sqlfluff.dialects import dialect_ansi as ansi
-from sqlfluff.dialects.dialect_clickhouse_keywords import UNRESERVED_KEYWORDS
+from sqlfluff.dialects.dialect_clickhouse_keywords import (
+    FORMAT_KEYWORDS,
+    UNRESERVED_KEYWORDS,
+)
 
 ansi_dialect = load_raw_dialect("ansi")
 
@@ -224,15 +228,67 @@ clickhouse_dialect.replace(
     SelectClauseTerminatorGrammar=ansi_dialect.get_grammar(
         "SelectClauseTerminatorGrammar"
     ).copy(
-        insert=[Ref.keyword("PREWHERE")],
+        insert=[
+            Ref.keyword("PREWHERE"),
+            Ref.keyword("INTO"),
+            Ref.keyword("FORMAT"),
+        ],
         before=Ref.keyword("WHERE"),
     ),
     FromClauseTerminatorGrammar=ansi_dialect.get_grammar("FromClauseTerminatorGrammar")
-    .copy(insert=[Ref.keyword("PREWHERE")], before=Ref.keyword("WHERE"))
+    .copy(
+        insert=[
+            Ref.keyword("PREWHERE"),
+            Ref.keyword("INTO"),
+            Ref.keyword("FORMAT"),
+        ],
+        before=Ref.keyword("WHERE"),
+    )
     .copy(insert=[Ref("SettingsClauseSegment")]),
 )
 
 
+class IntoOutfileClauseSegment(BaseSegment):
+    """An `INTO OUTFILE` clause like in `SELECT`."""
+
+    type = "into_outfile_clause"
+    match_grammar: Matchable = Sequence(
+        "INTO",
+        "OUTFILE",
+        Ref("QuotedLiteralSegment"),
+        Ref("FormatClauseSegment", optional=True),
+    )
+
+
+class FormatClauseSegment(BaseSegment):
+    """A `FORMAT` clause like in `SELECT`."""
+
+    type = "format_clause"
+    match_grammar: Matchable = Sequence(
+        "FORMAT",
+        OneOf(*[Ref.keyword(allowed_format) for allowed_format in FORMAT_KEYWORDS]),
+        Ref("SettingsClauseSegment", optional=True),
+    )
+
+
+class MergeTreesOrderByClauseSegment(BaseSegment):
+    """A `ORDER BY` clause for the MergeTree family engine."""
+
+    type = "merge_tree_order_by_clause"
+    match_grammar: Matchable = Sequence(
+        "ORDER",
+        "BY",
+        OneOf(
+            Sequence(
+                "TUPLE",
+                Bracketed(),  # tuple() not tuple
+            ),
+            Ref("BracketedColumnReferenceListGrammar"),
+            Ref("ColumnReferenceSegment"),
+        ),
+    )
+
+
 class PreWhereClauseSegment(BaseSegment):
     """A `PREWHERE` clause like in `SELECT` or `INSERT`."""
 
@@ -283,7 +339,11 @@ class SelectStatementSegment(ansi.SelectStatementSegment):
         insert=[Ref("PreWhereClauseSegment", optional=True)],
         before=Ref("WhereClauseSegment", optional=True),
     ).copy(
-        insert=[Ref("SettingsClauseSegment", optional=True)],
+        insert=[
+            Ref("FormatClauseSegment", optional=True),
+            Ref("IntoOutfileClauseSegment", optional=True),
+            Ref("SettingsClauseSegment", optional=True),
+        ],
     )
 
 
@@ -296,6 +356,28 @@ class UnorderedSelectStatementSegment(ansi.UnorderedSelectStatementSegment):
     )
 
 
+class WithFillSegment(ansi.WithFillSegment):
+    """Enhances `ORDER BY` clauses to include WITH FILL.
+
+    https://clickhouse.com/docs/en/sql-reference/statements/select/order-by#order-by-expr-with-fill-modifier
+    """
+
+    match_grammar: Matchable = Sequence(
+        "WITH",
+        "FILL",
+        Sequence("FROM", Ref("ExpressionSegment"), optional=True),
+        Sequence("TO", Ref("ExpressionSegment"), optional=True),
+        Sequence(
+            "STEP",
+            OneOf(
+                Ref("NumericLiteralSegment"),
+                Ref("IntervalExpressionSegment"),
+            ),
+            optional=True,
+        ),
+    )
+
+
 class BracketedArguments(ansi.BracketedArguments):
     """A series of bracketed arguments.
 
@@ -306,8 +388,7 @@ class BracketedArguments(ansi.BracketedArguments):
         Delimited(
             OneOf(
                 # Dataypes like Nullable allow optional datatypes here.
-                Ref("DatatypeIdentifierSegment"),
-                Ref("NumericLiteralSegment"),
+                Ref("DatatypeSegment"),
             ),
             # The brackets might be empty for some cases...
             optional=True,
@@ -315,6 +396,81 @@ class BracketedArguments(ansi.BracketedArguments):
     )
 
 
+class DatatypeSegment(BaseSegment):
+    """Support complex Clickhouse data types.
+
+    Complex data types are typically used in either DDL statements or as
+    the target type in casts.
+    """
+
+    type = "data_type"
+    match_grammar = OneOf(
+        Sequence(
+            StringParser("NULLABLE", CodeSegment, type="data_type_identifier"),
+            Bracketed(Ref("DatatypeSegment")),
+        ),
+        # double args
+        Sequence(
+            OneOf(
+                StringParser("DECIMAL", CodeSegment, type="data_type_identifier"),
+                StringParser("NUMERIC", CodeSegment, type="data_type_identifier"),
+            ),
+            Ref("BracketedArguments", optional=True),
+        ),
+        # single args
+        Sequence(
+            OneOf(
+                StringParser("DECIMAL32", CodeSegment, type="data_type_identifier"),
+                StringParser("DECIMAL64", CodeSegment, type="data_type_identifier"),
+                StringParser("DECIMAL128", CodeSegment, type="data_type_identifier"),
+                StringParser("DECIMAL256", CodeSegment, type="data_type_identifier"),
+            ),
+            Bracketed(Ref("NumericLiteralSegment")),  # scale
+        ),
+        Ref("TupleTypeSegment"),
+        Ref("DatatypeIdentifierSegment"),
+        Ref("NumericLiteralSegment"),
+        Sequence(
+            StringParser("DATETIME64", CodeSegment, type="data_type_identifier"),
+            Bracketed(
+                Delimited(
+                    Ref("NumericLiteralSegment"),  # precision
+                    Ref("QuotedLiteralSegment", optional=True),  # timezone
+                    # The brackets might be empty as well
+                    optional=True,
+                ),
+                optional=True,
+            ),
+        ),
+    )
+
+
+class TupleTypeSegment(ansi.StructTypeSegment):
+    """Expression to construct a Tuple datatype."""
+
+    match_grammar = Sequence(
+        "TUPLE",
+        Ref("TupleTypeSchemaSegment"),  # Tuple() can't be empty
+    )
+
+
+class TupleTypeSchemaSegment(BaseSegment):
+    """Expression to construct the schema of a Tuple datatype."""
+
+    type = "tuple_type_schema"
+    match_grammar = Bracketed(
+        Delimited(
+            Sequence(
+                Ref("SingleIdentifierGrammar"),
+                Ref("DatatypeSegment"),
+            ),
+            bracket_pairs_set="bracket_pairs",
+        ),
+        bracket_pairs_set="bracket_pairs",
+        bracket_type="round",
+    )
+
+
 class ArrayJoinClauseSegment(BaseSegment):
     """[LEFT] ARRAY JOIN does not support Join conditions and doesn't work as real JOIN.
 
@@ -509,18 +665,11 @@ class TableEngineSegment(BaseSegment):
     type = "engine"
     match_grammar = Sequence(
         "ENGINE",
-        Ref("EqualsSegment"),
+        Ref("EqualsSegment", optional=True),
         Sequence(
             Ref("TableEngineFunctionSegment"),
             AnySetOf(
-                Sequence(
-                    "ORDER",
-                    "BY",
-                    OneOf(
-                        Ref("BracketedColumnReferenceListGrammar"),
-                        Ref("ColumnReferenceSegment"),
-                    ),
-                ),
+                Ref("MergeTreesOrderByClauseSegment"),
                 Sequence(
                     "PARTITION",
                     "BY",
@@ -586,15 +735,7 @@ class DatabaseEngineSegment(BaseSegment):
         Sequence(
             Ref("DatabaseEngineFunctionSegment"),
             AnySetOf(
-                Sequence(
-                    "ORDER",
-                    "BY",
-                    OneOf(
-                        Ref("BracketedColumnReferenceListGrammar"),
-                        Ref("ColumnReferenceSegment"),
-                    ),
-                    optional=True,
-                ),
+                Ref("MergeTreesOrderByClauseSegment"),
                 Sequence(
                     "PARTITION",
                     "BY",
@@ -761,6 +902,53 @@ class CreateDatabaseStatementSegment(ansi.CreateDatabaseStatementSegment):
     )
 
 
+class RenameStatementSegment(BaseSegment):
+    """A `RENAME TABLE` statement.
+
+    As specified in
+    https://clickhouse.com/docs/en/sql-reference/statements/rename/
+    """
+
+    type = "rename_table_statement"
+
+    match_grammar = Sequence(
+        "RENAME",
+        OneOf(
+            Sequence(
+                "TABLE",
+                Delimited(
+                    Sequence(
+                        Ref("TableReferenceSegment"),
+                        "TO",
+                        Ref("TableReferenceSegment"),
+                    )
+                ),
+            ),
+            Sequence(
+                "DATABASE",
+                Delimited(
+                    Sequence(
+                        Ref("DatabaseReferenceSegment"),
+                        "TO",
+                        Ref("DatabaseReferenceSegment"),
+                    )
+                ),
+            ),
+            Sequence(
+                "DICTIONARY",
+                Delimited(
+                    Sequence(
+                        Ref("ObjectReferenceSegment"),
+                        "TO",
+                        Ref("ObjectReferenceSegment"),
+                    )
+                ),
+            ),
+        ),
+        Ref("OnClusterClauseSegment", optional=True),
+    )
+
+
 class CreateTableStatementSegment(ansi.CreateTableStatementSegment):
     """A `CREATE TABLE` statement.
 
@@ -1420,5 +1608,59 @@ class StatementSegment(ansi.StatementSegment):
             Ref("DropQuotaStatementSegment"),
             Ref("DropSettingProfileStatementSegment"),
             Ref("SystemStatementSegment"),
+            Ref("RenameStatementSegment"),
         ]
     )
+
+
+class LimitClauseComponentSegment(BaseSegment):
+    """A component of a `LIMIT` clause.
+
+    https://clickhouse.com/docs/en/sql-reference/statements/select/limit
+    """
+
+    type = "limit_clause_component"
+
+    match_grammar = OptionallyBracketed(
+        OneOf(
+            # Allow a number by itself OR
+            Ref("NumericLiteralSegment"),
+            # An arbitrary expression
+            Ref("ExpressionSegment"),
+        )
+    )
+
+
+class LimitClauseSegment(ansi.LimitClauseSegment):
+    """Overriding LimitClauseSegment to allow for additional segment parsing."""
+
+    match_grammar: Matchable = Sequence(
+        "LIMIT",
+        Indent,
+        Sequence(
+            Ref("LimitClauseComponentSegment"),
+            OneOf(
+                Sequence(
+                    "OFFSET",
+                    Ref("LimitClauseComponentSegment"),
+                ),
+                Sequence(
+                    # LIMIT 1,2 only accepts constants
+                    # and can't be bracketed like that LIMIT (1, 2)
+                    # but can be bracketed like that LIMIT (1), (2)
+                    Ref("CommaSegment"),
+                    Ref("LimitClauseComponentSegment"),
+                ),
+                optional=True,
+            ),
+            Sequence(
+                "BY",
+                OneOf(
+                    Ref("BracketedColumnReferenceListGrammar"),
+                    Ref("ColumnReferenceSegment"),
+                ),
+                optional=True,
+            ),
+        ),
+        Dedent,
+    )
