@@ -23,6 +23,7 @@ CURRENT_TIME
 CURRENT_TIMESTAMP
 CURRENT_USER
 DELETE
+DECLARE
 DISTINCT
 DROP
 ELSE
@@ -92,7 +93,8 @@ WHERE
 WITH
 """
 
-snowflake_unreserved_keywords = """ABORT
+snowflake_unreserved_keywords = """
+ABORT
 ABORT_STATEMENT
 ACCESS
 ACCOUNT
@@ -100,12 +102,13 @@ ACCOUNTS
 ADD
 ADMIN
 AFTER
-ALLOWED_IP_LIST
-ALLOWED_NETWORK_RULE_LIST
-ALLOWED_VALUES
+AGGREGATE
 ALLOW_DUPLICATE
 ALLOW_OVERLAPPING_EXECUTION
 ALLOW_WRITES
+ALLOWED_IP_LIST
+ALLOWED_NETWORK_RULE_LIST
+ALLOWED_VALUES
 ALWAYS
 API
 API_INTEGRATION
@@ -118,13 +121,13 @@ ATTACH
 AUTHORIZATION
 AUTHORIZATIONS
 AUTO
-AUTOINCREMENT
 AUTO_COMPRESS
 AUTO_INCREMENT
 AUTO_INGEST
 AUTO_REFRESH
 AUTO_RESUME
 AUTO_SUSPEND
+AUTOINCREMENT
 AVRO
 AWS_KEY_ID
 AWS_ROLE
@@ -161,12 +164,12 @@ CALLED
 CALLER
 CASCADE
 CASE
-CASES
 CASE_INSENSITIVE
 CASE_SENSITIVE
+CASES
 CHAIN
-CHANGES
 CHANGE_TRACKING
+CHANGES
 CHARACTER
 CLONE
 CLUSTER
@@ -205,10 +208,10 @@ CURSOR
 CYCLE
 DAILY
 DATA
-DATABASE
-DATABASES
 DATA_FORMAT
 DATA_RETENTION_TIME_IN_DAYS
+DATABASE
+DATABASES
 DATE
 DATE_FORMAT
 DAYS_TO_EXPIRY
@@ -230,9 +233,9 @@ DETAILED_OUTPUT
 DIRECTION
 DIRECTORY
 DISABLE
-DISABLED
 DISABLE_AUTO_CONVERT
 DISABLE_SNOWFLAKE_DATA
+DISABLED
 DISPLAY_NAME
 DO
 DOMAIN
@@ -243,14 +246,14 @@ EMAIL
 EMPTY
 EMPTY_FIELD_AS_NULL
 ENABLE
-ENABLED
 ENABLE_OCTAL
+ENABLED
 ENCODING
 ENCRYPTION
 END
 END_TIMESTAMP
-ENFORCED
 ENFORCE_LENGTH
+ENFORCED
 ENUM
 ERROR
 ERROR_INTEGRATION
@@ -259,6 +262,7 @@ ESCAPE
 ESCAPE_UNENCLOSED_FIELD
 EVENT
 EXCEPT
+EXCEPTION
 EXCHANGE
 EXCLUDE
 EXECUTE
@@ -274,9 +278,9 @@ FIELD_DELIMITER
 FIELD_OPTIONALITY_ENCLOSED_BY
 FIELD_OPTIONALLY_ENCLOSED_BY
 FILE
-FILES
 FILE_EXTENSION
 FILE_FORMAT
+FILES
 FILTER
 FINAL
 FIRST
@@ -285,8 +289,8 @@ FOR
 FORCE
 FOREIGN
 FORMAT
-FORMATS
 FORMAT_NAME
+FORMATS
 FREQUENCY
 FUNCTION
 FUNCTIONS
@@ -348,8 +352,8 @@ LISTING
 LOCAL
 LOCATION
 LOCKS
-LOGIN_NAME
 LOG_LEVEL
+LOGIN_NAME
 LS
 LZO
 M
@@ -359,24 +363,24 @@ MANAGED
 MASKING
 MASTER_KEY
 MATCH
+MATCH_BY_COLUMN_NAME
 MATCHED
 MATCHES
-MATCH_BY_COLUMN_NAME
 MATERIALIZED
-MAXVALUE
 MAX_BATCH_ROWS
 MAX_CLUSTER_COUNT
 MAX_CONCURRENCY_LEVEL
 MAX_DATA_EXTENSION_TIME_IN_DAYS
 MAX_FILE_SIZE
 MAX_SIZE
+MAXVALUE
 MEASURES
 MERGE
 MIDDLE_NAME
+MIN_CLUSTER_COUNT
 MINS_TO_BYPASS_MFA
 MINS_TO_UNLOCK
 MINVALUE
-MIN_CLUSTER_COUNT
 ML
 MODEL
 MODIFIED_AFTER
@@ -400,17 +404,17 @@ NOTIFICATION_INTEGRATION
 NOTIFICATION_PROVIDER
 NOTIFY
 NOTIFY_USERS
-NULLS
 NULL_IF
+NULLS
 OBJECT
 OBJECTS
 OFF
 OFFSET
 OMIT
-ONE
-ONLY
 ON_ERROR
 ON_EVENT
+ONE
+ONLY
 OPERATE
 OPTIMIZATION
 OPTION
@@ -437,8 +441,8 @@ PER
 PERCENT
 PERMUTE
 PIPE
-PIPES
 PIPE_EXECUTION_PAUSED
+PIPES
 PIVOT
 POLICIES
 POLICY
@@ -464,8 +468,8 @@ READ
 RECLUSTER
 RECORD_DELIMITER
 RECURSIVE
-REFERENCES
 REFERENCE_USAGE
+REFERENCES
 REFRESH
 REFRESH_MODE
 REFRESH_ON_CREATE
@@ -488,10 +492,10 @@ RESULT
 RESULTSET
 RESUME
 RETURN
-RETURNS
 RETURN_ALL_ERRORS
 RETURN_ERRORS
 RETURN_FAILED_ONLY
+RETURNS
 RM
 ROLE
 ROLES
@@ -525,8 +529,8 @@ SESSION
 SESSION_USER
 SETS
 SHARE
-SHARES
 SHARE_RESTRICTIONS
+SHARES
 SHOW
 SHOW_INITIAL_ROWS
 SINGLE
@@ -543,12 +547,12 @@ SNOWFLAKE_SSE
 SOURCE_COMPRESSION
 SQL
 STAGE
-STAGES
 STAGE_COPY_OPTIONS
 STAGE_FILE_FORMAT
+STAGES
 STANDARD
-STARTS
 START_TIMESTAMP
+STARTS
 STATEMENT
 STATEMENT_QUEUED_TIMEOUT_IN_SECONDS
 STATEMENT_TIMEOUT_IN_SECONDS
@@ -573,8 +577,8 @@ STRIP_OUTER_ELEMENT
 SUBPATH
 SUPPORT
 SUSPEND
-SUSPENDED
 SUSPEND_IMMEDIATE
+SUSPENDED
 SWAP
 SYSDATE
 SYSTEM
@@ -592,9 +596,9 @@ TEMPORARY
 TERSE
 TEXT
 TIME
+TIME_FORMAT
 TIMESTAMP
 TIMESTAMP_FORMAT
-TIME_FORMAT
 TOP
 TRACE
 TRACE_LEVEL
@@ -615,11 +619,11 @@ URL
 US
 USAGE
 USE
+USE_ANY_ROLE
 USER
-USERS
 USER_TASK_MANAGED_INITIAL_WAREHOUSE_SIZE
 USER_TASK_TIMEOUT_MS
-USE_ANY_ROLE
+USERS
 UTF8
 VALIDATE_UTF8
 VALIDATION_MODE
@@ -635,9 +639,9 @@ VOLUME
 VOLUMES
 WAIT_FOR_COMPLETION
 WAREHOUSE
-WAREHOUSES
 WAREHOUSE_SIZE
 WAREHOUSE_TYPE
+WAREHOUSES
 WARN
 WEEKLY
 WINDOW
